/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { RemoveUpstreamBatch } from "../models/RemoveUpstreamBatch";
import type { Upstream } from "../models/Upstream";
import type { UpstreamData } from "../models/UpstreamData";
import type { UpstreamId } from "../models/UpstreamId";
import { request as __request } from "../core/request";

export class UpstreamsService {
  /**
   * Adds an upstream to the account.
   * @param accountId
   * @param requestBody
   * @returns Upstream Success.
   * @throws ApiError
   */
  public static async addUpstream(accountId: AccountId, requestBody: UpstreamData): Promise<Upstream> {
    const result = await __request({
      method: "POST",
      path: `/v1/accounts/${accountId}/upstreams`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Removes multiple upstreams from the account.
   * @param accountId
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async removeUpstreamBatch(accountId: AccountId, requestBody: RemoveUpstreamBatch): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/upstreams`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Removes an upstream from the account.
   * @param accountId
   * @param upstreamId
   * @returns void
   * @throws ApiError
   */
  public static async removeUpstream(accountId: AccountId, upstreamId: UpstreamId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/accounts/${accountId}/upstreams/${upstreamId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
